@@ -1,3 +1,5 @@
+import numpy as np
+import os
 
 
 def calculate_values_from_packet_data(data):
@@ -23,10 +25,21 @@ def calculate_values_from_packet_data(data):
         # byte_a is the most significant byte and byte_b is
         # the least significant byte.
         byte_a, byte_b = data[index], data[index + 1]
-        values.append((byte_a << 8) | byte_b)
+        val = (byte_a << 8) | byte_b
+        # For some reason the data comes in upside down.
+        # Flip data around a horizontal axis.
+        val = (val - 1024) * -1
+        values.append(val)
 
     return values
 
 
 def calculate_heart_rate(data):
-    return 60
\ No newline at end of file
+    return np.fft.rfft(data)
+
+
+def get_mock_data_list():
+    package_dir = os.path.dirname(os.path.abspath(__file__))
+    mock_data_dir = os.path.join(os.path.dirname(package_dir), 'mock-data')
+    return mock_data_dir, os.listdir(mock_data_dir)
+
