@@ -2,7 +2,7 @@ import random
 import unittest
 from olimex.constants import PACKET_SLICES
 from olimex.exg import PacketStreamReader
-from olimex.mock import SerialMocked, packet_generator
+from olimex.mock import packet_generator, FakeSerialByteArray
 from olimex.utils import calculate_values_from_packet_data
 
 
@@ -19,11 +19,11 @@ class PacketStreamReaderTestCase(unittest.TestCase):
         packet3 = next(packet_gen)
         byte_array.extend(packet3)
 
-        with SerialMocked(byte_array) as serial_obj:
-            reader = PacketStreamReader(serial_obj)
-            self.assertEqual(packet1, reader._get_next_packet())
-            self.assertEqual(packet2, reader._get_next_packet())
-            self.assertEqual(packet3, reader._get_next_packet())
+        serial = FakeSerialByteArray(byte_array)
+        reader = PacketStreamReader(serial)
+        self.assertEqual(packet1, reader._get_next_packet())
+        self.assertEqual(packet2, reader._get_next_packet())
+        self.assertEqual(packet3, reader._get_next_packet())
 
     def test_get_next_packet_values(self):
         byte_array = bytearray()
@@ -41,10 +41,10 @@ class PacketStreamReaderTestCase(unittest.TestCase):
         packet2_data = packet2[PACKET_SLICES['data']]
         packet2_value = calculate_values_from_packet_data(packet2_data)
 
-        with SerialMocked(byte_array) as serial_obj:
-            reader = PacketStreamReader(serial_obj)
-            self.assertEqual(packet1_value, reader._get_next_packet_values())
-            self.assertEqual(packet2_value, next(reader))
+        serial = FakeSerialByteArray(byte_array)
+        reader = PacketStreamReader(serial)
+        self.assertEqual(packet1_value, reader._get_next_packet_values())
+        self.assertEqual(packet2_value, next(reader))
 
 
 class UtilsTestCase(unittest.TestCase):
